searchData={"items":[{"type":"module","title":"Omni","doc":"![Omni](https://raw.githubusercontent.com/lebrunel/omni/main/media/poster.png)\n\n![License](https://img.shields.io/github/license/lebrunel/omni?color=informational)\n\nOmni focusses on one thing only - being a chat interface to *any* LLM provider.\nIf you want a full featured client for a specific provider, supporting all\navailable API endpoints, this is probably not it. If you want a single client\nto generate chat completions with literally any LLM backend, Omni is for you.\n\n- 🧩 `Omni.Provider` behaviour to create integrations with any LLM provider.\nBuilt-in providers for:\n  - [`Anthropic`](`Omni.Providers.Anthropic`) - chat with any of of the Claude models.\n  - [`Google`](`Omni.Providers.Google`) - chat with any of of the Gemini models.\n  - [`Ollama`](`Omni.Providers.Ollama`) - use Ollama to chat with any local model.\n  - [`OpenAI`](`Omni.Providers.OpenAI`) - chat with ChatGPT or **any** other OpenAI compatible API.\n- 🛜 Streaming API requests\n  - Stream to an Enumerable\n  - Or stream messages to any Elixir process\n- 💫 Simple to use and easily customisable","ref":"Omni.html"},{"type":"module","title":"Installation - Omni","doc":"The package can be installed by adding `omni` to your list of dependencies\nin `mix.exs`.\n\n```elixir\ndef deps do\n  [\n    {:omni, \"0.1.1\"}\n  ]\nend\n```","ref":"Omni.html#module-installation"},{"type":"module","title":"Quickstart - Omni","doc":"To chat with an LLM, initialize a [`t:provider/0`](`t:Omni.Provider.t/0`) with\n`init/2`, and then send a [`t:request/0`](`t:Omni.Provider.request/0`), using\none of `generate/2`, `async/2` or `stream/2`. Refer to the schema\ndocumentation for each provider to ensure you construct a valid request.\n\n```elixir\niex> provider = Omni.init(:openai)\niex> Omni.generate(provider, model: \"gpt-4o\", messages: [\n...>   %{role: \"user\", content: \"Write a haiku about the Greek Gods\"}\n...> ])\n{:ok, %{\"object\" => \"chat.completion\", \"choices\" => [...]}}\n```","ref":"Omni.html#module-quickstart"},{"type":"module","title":"Streaming - Omni","doc":"Omni supports streaming request through `async/2` or `stream/2`.\n\nCalling `async/2` returns a `t:Task.t/0`, which asynchronously sends text\ndelta messages to the calling process. Using the `:stream_to` request option\nallows you to control the receiving process.\n\nThe example below demonstrates making a streaming request in a LiveView event,\nand sends each of the streaming messages back to the same LiveView process.\n\n```elixir\ndefmodule MyApp.ChatLive do\n  use Phoenix.LiveView\n\n  # When the client invokes the \"prompt\" event, create a streaming request and\n  # asynchronously send messages back to self.\n  def handle_event(\"prompt\", %{\"message\" => prompt}, socket) do\n    {:ok, task} = Omni.async(Omni.init(:openai), [\n      model: \"gpt-4o\",\n      messages: [\n        %{role: \"user\", content: \"Write a haiku about the Greek Gods\"}\n      ]\n    ])\n\n    {:noreply, assign(socket, current_request: task)}\n  end\n\n  # The streaming request sends messages back to the LiveView process.\n  def handle_info({_request_pid, {:data, _data}} = message, socket) do\n    pid = socket.assigns.current_request.pid\n    case message do\n      {:omni, ^pid, {:chunk, %{\"choices\" => choices, \"finish_reason\" => nil}}} ->\n        # handle each streaming chunk\n\n      {:omni, ^pid, {:chunk, %{\"choices\" => choices}}} ->\n        # handle the final streaming chunk\n    end\n  end\n\n  # Tidy up when the request is finished\n  def handle_info({ref, {:ok, _response}}, socket) do\n    Process.demonitor(ref, [:flush])\n    {:noreply, assign(socket, current_request: nil)}\n  end\nend\n```\n\nAlternatively, use `stream/2` to collect the streaming responses into an\n`t:Enumerable.t/0` that can be used with Elixir's `Stream` functions.\n\n```elixir\niex> provider = Omni.init(:openai)\niex> {:ok, stream} = Omni.stream(provider, model: \"gpt-4o\", messages: [\n...>   %{role: \"user\", content: \"Write a haiku about the Greek Gods\"}\n...> ])\n\niex> stream\n...> |> Stream.each(&IO.inspect/1)\n...> |> Stream.run()\n```\n\nBecause this function builds the `t:Enumerable.t/0` by calling `receive/1`,\ntake care using `stream/2` inside `GenServer` callbacks as it may cause the\nGenServer to misbehave.","ref":"Omni.html#module-streaming"},{"type":"function","title":"Omni.async/2","doc":"Asynchronously generates a chat completion using the given [`t:provider/0`](`t:Omni.Provider.t/0`)\nand [`t:request/0`](`t:Omni.Provider.request/0`). Returns a `t:Task.t/0`.\n\nWithin your code, you should manually define a `receive/1` block (or setup\n`c:GenServer.handle_info/2` callbacks) to receive the message stream.","ref":"Omni.html#async/2"},{"type":"function","title":"Additional request options - Omni.async/2","doc":"In addition to the [`t:request/0`](`t:Omni.Provider.request/0`) options for\nthe given [`t:provider/0`](`t:Omni.Provider.t/0`), this function accepts the\nfollowing options:\n\n- `:stream-to` - Pass a `t:pid/0` to control the receiving process.","ref":"Omni.html#async/2-additional-request-options"},{"type":"function","title":"Example - Omni.async/2","doc":"```elixir\niex> provider = Omni.init(:openai)\niex> Omni.async(provider, model: \"gpt-4o\", messages: [\n  %{role: \"user\", content: \"Write a haiku about the Greek Gods\"}\n])\n{:ok, %Task{pid: pid, ref: ref}}\n\n# Somewhere in your code\nreceive do\n  {:omni, ^pid, {:chunk, chunk}} ->  # handle chunk\n  {^ref, {:ok, res}} ->              # handle final response\n  {^ref, {:error, error}} ->         # handle error\n  {:DOWN, _ref, _, _pid, _reason} -> # handle DOWN signal\nend\n```","ref":"Omni.html#async/2-example"},{"type":"function","title":"Omni.async!/2","doc":"As `async/2` but raises in the case of an error.","ref":"Omni.html#async!/2"},{"type":"function","title":"Omni.generate/2","doc":"Generates a chat completion using the given [`t:provider/0`](`t:Omni.Provider.t/0`)\nand [`t:request/0`](`t:Omni.Provider.request/0`). Synchronously returns a\n[`t:response/0`](`t:Omni.Provider.response/0`).","ref":"Omni.html#generate/2"},{"type":"function","title":"Example - Omni.generate/2","doc":"```elixir\niex> provider = Omni.init(:openai)\niex> Omni.generate(provider, model: \"gpt-4o\", messages: [\n  %{role: \"user\", content: \"Write a haiku about the Greek Gods\"}\n])\n{:ok, %{\"message\" => %{\n  \"content\" => \"Mount Olympus stands,\\nImmortal whispers echo—\\nZeus reigns, thunder roars.\"\n}}}\n```","ref":"Omni.html#generate/2-example"},{"type":"function","title":"Omni.generate!/2","doc":"As `generate/2` but raises in the case of an error.","ref":"Omni.html#generate!/2"},{"type":"function","title":"Omni.init/2","doc":"","ref":"Omni.html#init/2"},{"type":"function","title":"Omni.stream/2","doc":"Asynchronously generates a chat completion using the given [`t:provider/0`](`t:Omni.Provider.t/0`)\nand [`t:request/0`](`t:Omni.Provider.request/0`). Returns an `t:Enumerable.t/0`.\n\nBecause this function builds the `t:Enumerable.t/0` by calling `receive/1`,\nusing this function inside `GenServer` callbacks may cause the GenServer to\nmisbehave. In such cases, use `async/2` instead.","ref":"Omni.html#stream/2"},{"type":"function","title":"Example - Omni.stream/2","doc":"```elixir\niex> provider = Omni.init(:openai)\niex> {:ok, stream} = Omni.stream(provider, model: \"gpt-4o\", messages: [\n  %{role: \"user\", content: \"Write a haiku about the Greek Gods\"}\n])\n\niex> stream\n...> |> Stream.each(&IO.inspect/1)\n...> |> Stream.run()\n```","ref":"Omni.html#stream/2-example"},{"type":"function","title":"Omni.stream!/2","doc":"As `stream/2` but raises in the case of an error.","ref":"Omni.html#stream!/2"},{"type":"behaviour","title":"Omni.Provider","doc":"A Provider represents an LLM provider service. By fully implementing the\nProvider behaviour, a module can be made to support any LLM backend available.\n\nOut of the box, Omni ships Providers for:\n\n- [`Anthropic`](`Omni.Providers.Anthropic`) - chat with any of of the Claude models\n- [`Google`](`Omni.Providers.Google`) - chat with any of of the Gemini models\n- [`Ollama`](`Omni.Providers.Ollama`) - use Ollama to chat with any local model\n- [`OpenAI`](`Omni.Providers.OpenAI`) - configurable with any other OpenAI compatible chat API","ref":"Omni.Provider.html"},{"type":"behaviour","title":"Implementing a Provider - Omni.Provider","doc":"This module also provides a number of macros that streamline creating a\nProvider implementation. Most callbacks can be implemented simply by calling\nthe relevant macro.\n\n```elixir\ndefmodule MyLLM do\n  use Omni.Provider\n  @api_key Application.compile_env(:omni, [__MODULE__, :api_key])\n\n  # Macros\n\n  base_url \"http://localhost:1234/api\"\n  headers %{authorization: \"Bearer #{@api_key}\"}\n  endpoint \"/chat\"\n  stream_endpoint \"/chat\", stream: true\n\n  schema [\n    # define NimbleOptions schema for chat request params\n  ]\n\n  # Callbacks\n\n  @impl true\n  def parse_stream(data) do\n    # parse binary data stream into chunks\n    {:cont, [chunks]}\n  end\n\n  @impl true\n  def merge_stream(body, data) do\n    # merge stream data chunks into single response\n    body\n  end\nend\n```","ref":"Omni.Provider.html#module-implementing-a-provider"},{"type":"behaviour","title":"Extending a Provider - Omni.Provider","doc":"The `extend/2` macro can be used to inherit from an already implemented\nProvider. For example, if you were implementing a LLM service that was OpenAI\ncompatible, but required a different kind of authorization header.\n\n```elixir\ndefmodule MyLLM do\n  use Omni.Provider\n  @api_key Application.compile_env(:omni, [__MODULE__, :api_key])\n\n  extends Omni.Providers.OpenAI, except: [:headers]\n  headers %{x_auth_token: @api_key}\nend\n```","ref":"Omni.Provider.html#module-extending-a-provider"},{"type":"macro","title":"Omni.Provider.base_url/1","doc":"Defines the base URL for the Provider.","ref":"Omni.Provider.html#base_url/1"},{"type":"callback","title":"Omni.Provider.base_url/1","doc":"Invoked to return the Provider base URL as a string.\n\nFor a simple implementation, prefer the `base_url/1` macro. Manually\nimplementing the callback allows using the initialization options to\ndynamically generate the return value.","ref":"Omni.Provider.html#c:base_url/1"},{"type":"callback","title":"Omni.Provider.body/1","doc":"Invoked to return the Provider request body as a map.\n\nThis callback is optional. If not implemented, the default implementaion\nreturns the user `t:request/0` options as a `t:map/0`.","ref":"Omni.Provider.html#c:body/1"},{"type":"callback","title":"Omni.Provider.endpoint/1","doc":"Invoked to return the Provider chat endpoint and any default request options\nfor that endpoint. Returns a tuple.\n\nFor a simple implementation, prefer the `endpoint/2` macro. Manually\nimplementing the callback allows using the user `t:request/0` options to\ndynamically generate the return value.","ref":"Omni.Provider.html#c:endpoint/1"},{"type":"macro","title":"Omni.Provider.endpoint/2","doc":"Defines the chat endpoint for the Provider.\n\nOptionally accepts list of default `t:request/0` options for this endpoint.","ref":"Omni.Provider.html#endpoint/2"},{"type":"macro","title":"Omni.Provider.extends/2","doc":"Extends an existing Provider module by delegating all callbacks to the parent\nmodule.\n\nUse the `:except` option to specify which callbacks shouldn't be delegated to\nthe parent, allowing you to override with a tailored implementation.","ref":"Omni.Provider.html#extends/2"},{"type":"macro","title":"Omni.Provider.headers/1","doc":"Defines the request `t:headers/0` for the Provider.","ref":"Omni.Provider.html#headers/1"},{"type":"callback","title":"Omni.Provider.headers/1","doc":"Invoked to return the Provider request `t:headers/0`.\n\nFor a simple implementation, prefer the `headers/1` macro. Manually\nimplementing the callback allows using the initialization options to\ndynamically generate the return value.\n\nThis callback is optional. If not implemented, the default implementaion\nreturns an empty set of headers.","ref":"Omni.Provider.html#c:headers/1"},{"type":"function","title":"Omni.Provider.init/2","doc":"Initializes a new instance of a Provider, using the given module or `t:alt/0`\nalias.\n\nAccepts a list of initialization options. Refer to the Provider module docs\nfor details of the accepted options.","ref":"Omni.Provider.html#init/2"},{"type":"function","title":"Example - Omni.Provider.init/2","doc":"```elixir\niex> Omni.Provider.init(:openai)\n%Omni.Provider{mod: Omni.Providers.OpenAI, req: %Req.Request{}}\n```","ref":"Omni.Provider.html#init/2-example"},{"type":"callback","title":"Omni.Provider.merge_stream/2","doc":"Invoked to reconstruct a streaming data chunk back into a full response body.\n\nReceives the response body and a single streaming message. The body should\nbe returned with the message merged into it.\n\nThis callback is optional. If not implemented, the default implementaion\nalways returns the body as an empty string. If a Provider does not implement\nthis callback, calling `Task.await(stream_request_task)` will return the body\nas an empty string, but will still send streaming messages to the specified\nprocess.","ref":"Omni.Provider.html#c:merge_stream/2"},{"type":"callback","title":"Omni.Provider.parse_stream/1","doc":"Invoked to parse a streaming request data chunk into a list of one or more\nstructured messages.\n\nReceives a binary data chunk.\n\nReturning `{:cont, messages}` emits each of the messages and continues\nstreaming chunks.\n\nReturning `{:halt, messages}` emits each of the messages and cancels the\nstreaming request.","ref":"Omni.Provider.html#c:parse_stream/1"},{"type":"callback","title":"Omni.Provider.schema/0","doc":"Invoked to return the Provider chat schema, used to validate the `t:request/0`\noptions.\n\nPrefer the `schema/1` macro over a manual implementation.","ref":"Omni.Provider.html#c:schema/0"},{"type":"macro","title":"Omni.Provider.schema/1","doc":"Defines the schema for the Provider `t:request/0` options.\n\nSchemas should be defined as a `t:NimbleOptions.schema/0`.","ref":"Omni.Provider.html#schema/1"},{"type":"callback","title":"Omni.Provider.stream_endpoint/1","doc":"Invoked to return the Provider chat streaming endpoint and any default request\noptions for that endpoint. Returns a tuple.\n\nFor a simple implementation, prefer the `stream_endpoint/2` macro. Manually\nimplementing the callback allows using the user `t:request/0` options to\ndynamically generate the return value.","ref":"Omni.Provider.html#c:stream_endpoint/1"},{"type":"macro","title":"Omni.Provider.stream_endpoint/2","doc":"Defines the streaming chat endpoint for the Provider.\n\nOptionally accepts list of default `t:request/0` options for this endpoint.","ref":"Omni.Provider.html#stream_endpoint/2"},{"type":"type","title":"Omni.Provider.alt/0","doc":"Alt name\n\nAccepted aliases for the built in Provider modules.","ref":"Omni.Provider.html#t:alt/0"},{"type":"type","title":"Omni.Provider.headers/0","doc":"Request headers\n\nCan be any Enumerable containing keys and values. Handled by `Req` as follows:\n\n- atom header names are turned into strings, replacing _ with -. For example, :user_agent becomes \"user-agent\".\n- string header names are downcased.","ref":"Omni.Provider.html#t:headers/0"},{"type":"type","title":"Omni.Provider.init_opts/0","doc":"Initialization options.\n\nAn arbitrary keyword list of options to initialize the Provider.","ref":"Omni.Provider.html#t:init_opts/0"},{"type":"type","title":"Omni.Provider.request/0","doc":"An arbitrary keyword list of request options for the LLM.\n\nWhilst there are some similarities across providers, refer to the\ndocumentation for each provider to ensure you construct a valid request.","ref":"Omni.Provider.html#t:request/0"},{"type":"type","title":"Omni.Provider.response/0","doc":"An arbitrary map representing the response from the LLM provider.\n\nRefer to the documentation for each provider to understand the expected\nresponse format.","ref":"Omni.Provider.html#t:response/0"},{"type":"type","title":"Omni.Provider.t/0","doc":"Provider struct\n\nOnce initialized, is used to make subsequent API requests.","ref":"Omni.Provider.html#t:t/0"},{"type":"module","title":"Omni.Providers.Anthropic","doc":"Provider implementation for the [Anthropic Messages API](https://docs.anthropic.com/en/api/messages).\nUse this Provider to chat with any of the [Claude 3](https://www.anthropic.com/news/claude-3-family)\nmodels.","ref":"Omni.Providers.Anthropic.html"},{"type":"module","title":"Authorization - Omni.Providers.Anthropic","doc":"Obtain an API key from the [Anthropic Developer Console](https://console.anthropic.com)\nand add it to your application's `config.exs`:\n\n```elixir\nconfig :omni, Omni.Providers.Anthropic, \"sk-ant-api-notarealkey\"\n```\n\nAlternatively, pass the API key to `Onmi.init/2`:\n\n```elixir\niex> Omni.init(:anthropic, api_key: api_key)\n%Omni.Provider{mod: Omni.Providers.Anthropic, req: %Req.Request{}}\n```","ref":"Omni.Providers.Anthropic.html#module-authorization"},{"type":"function","title":"Omni.Providers.Anthropic.schema/0","doc":"Returns the schema for this Provider.","ref":"Omni.Providers.Anthropic.html#schema/0"},{"type":"function","title":"Schema - Omni.Providers.Anthropic.schema/0","doc":"* `:model` (`t:String.t/0`) - Required. The model that will complete your prompt.\n\n* `:messages` (list of `t:map/0`) - Required. Input messages.\n\n* `:max_tokens` (`t:integer/0`) - The maximum number of tokens to generate before stopping. The default value is `4096`.\n\n* `:metadata` (`t:map/0`) - A map describing metadata about the request.\n\n  * `:user_id` (`t:String.t/0`) - An external identifier for the user who is associated with the request.\n\n* `:stop_sequences` (list of `t:String.t/0`) - Custom text sequences that will cause the model to stop generating.\n\n* `:stream` (`t:boolean/0`) - Whether to incrementally stream the response using server-sent events.\n\n* `:system` (`t:String.t/0`) - System prompt.\n\n* `:temperature` (`t:float/0`) - Amount of randomness injected into the response.\n\n* `:tools` (list of `t:map/0`) - A list of tools the model may call.\n\n* `:tool_choice` (`t:map/0`) - How to use the provided tools.\n\n  * `:type` - Required. How the model should use the provided tools.\n\n  * `:name` (`t:String.t/0`) - The name of the tool to use.\n\n* `:top_k` (`t:integer/0`) - Only sample from the top K options for each subsequent token.\n\n* `:top_p` (`t:float/0`) - Amount of randomness injected into the response.","ref":"Omni.Providers.Anthropic.html#schema/0-schema"},{"type":"module","title":"Omni.Providers.Google","doc":"Provider implementation for the [Google Gemini API](https://ai.google.dev/gemini-api/docs).\nUse this Provider to chat with any of the Gemini models.","ref":"Omni.Providers.Google.html"},{"type":"module","title":"Authorization - Omni.Providers.Google","doc":"Obtain an API key from the [Google AI Studio](https://aistudio.google.com)\nand add it to your application's `config.exs`:\n\n```elixir\nconfig :omni, Omni.Providers.Google, \"NotaRealKey\"\n```\n\nAlternatively, pass the API key to `Onmi.init/2`:\n\n```elixir\niex> Omni.init(:google, api_key: api_key)\n%Omni.Provider{mod: Omni.Providers.Google, req: %Req.Request{}}\n```","ref":"Omni.Providers.Google.html#module-authorization"},{"type":"function","title":"Omni.Providers.Google.schema/0","doc":"Returns the schema for this Provider.","ref":"Omni.Providers.Google.html#schema/0"},{"type":"function","title":"Schema - Omni.Providers.Google.schema/0","doc":"* `:model` (`t:String.t/0`) - Required. Name of the model to use.\n\n* `:contents` (list of `t:map/0`) - Required. The base structured datatype containing multi-part content of a message.\n\n* `:system` (`t:map/0`) - Developer set system instruction.\n\n  * `:text` (`t:String.t/0`) - Required. System text.\n\n* `:tools` (list of `t:map/0`) - A list of Tools the model may use to generate the next response.\n\n* `:tool_config` (`t:map/0`) - Tool configuration for any Tool specified in the request.\n\n  * `:function_calling_config` (`t:map/0`) - Function calling config.\n\n    * `:mode` - Specifies the mode in which function calling should execute.\n\n    * `:allowed_function_names` (list of `t:String.t/0`) - A set of function names that, when provided, limits the functions the model will call.\n\n* `:generation` (`t:map/0`) - Configuration options for model generation and outputs.\n\n  * `:stop_sequences` (list of `t:String.t/0`) - Set of character sequences that will stop output generation.\n\n  * `:response_mime_type` - Output response mimetype of the generated candidate text.\n\n  * `:response_schema` (`t:map/0`) - Output response schema of the generated candidate text.\n\n  * `:candidate_count` (`t:integer/0`) - Number of generated responses to return.\n\n  * `:max_output_tokens` (`t:integer/0`) - The maximum number of tokens to include in a candidate.\n\n  * `:temperature` (`t:float/0`) - Controls the randomness of the output. Between 0.0 and 2.0.\n\n  * `:top_p` (`t:float/0`) - The maximum cumulative probability of tokens to consider when sampling.\n\n  * `:top_k` (`t:integer/0`) - The maximum number of tokens to consider when sampling.\n\n* `:safety` (list of `t:map/0`) - A list of unique SafetySetting instances for blocking unsafe content.","ref":"Omni.Providers.Google.html#schema/0-schema"},{"type":"module","title":"Omni.Providers.Ollama","doc":"Provider implementation for [Ollama](https://ollama.com/), using the\n[Ollama Chat API](https://github.com/ollama/ollama/blob/main/docs/api.md#generate-a-chat-completion).\nUse this Provider to chat with pretty much any local and open model (Llama 3,\nMistral, Gemma, and [many more](https://ollama.com/library)).","ref":"Omni.Providers.Ollama.html"},{"type":"module","title":"Base URL - Omni.Providers.Ollama","doc":"By default the Ollama Provider uses the base URL of `\"http://localhost:11434/api\"`.\nIf you need to change this, pass the `:base_url` option to `Omni.init/2`:\n\n```elixir\niex> Omni.init(:ollama, base_url: \"https://ollama.mydomain.com/api\")\n%Omni.Provider{mod: Omni.Providers.Ollama, req: %Req.Request{}}\n```","ref":"Omni.Providers.Ollama.html#module-base-url"},{"type":"function","title":"Omni.Providers.Ollama.schema/0","doc":"Returns the schema for this Provider.","ref":"Omni.Providers.Ollama.html#schema/0"},{"type":"function","title":"Schema - Omni.Providers.Ollama.schema/0","doc":"* `:model` (`t:String.t/0`) - Required. The ollama model name.\n\n* `:messages` (list of `t:map/0`) - Required. List of messages - used to keep a chat memory.\n\n* `:format` (`t:String.t/0`) - Set the expected format of the response (`json`).\n\n* `:stream` (`t:boolean/0`) - Whether to stream the response. The default value is `false`.\n\n* `:keep_alive` - How long to keep the model loaded.\n\n* `:options` - Additional advanced [model parameters](https://github.com/jmorganca/ollama/blob/main/docs/modelfile.md#valid-parameters-and-values).","ref":"Omni.Providers.Ollama.html#schema/0-schema"},{"type":"module","title":"Omni.Providers.OllamaGen","doc":"An alternative Provider implementation for [Ollama](https://ollama.com/), using the\n[Ollama Completion API](https://github.com/ollama/ollama/blob/main/docs/api.md#generate-a-completion).\nThis Provider is preferred when you need fine grained control over the prompt\ntemplates, that isn't possible using the normal chat API.\n\nThis Provider extends tha `Omni.Providers.Ollama` Provider, and so the [base URL](`Omni.Providers.Ollama#module-base-url`)\ncan be configured in the same way.","ref":"Omni.Providers.OllamaGen.html"},{"type":"function","title":"Omni.Providers.OllamaGen.schema/0","doc":"Returns the schema for this Provider.","ref":"Omni.Providers.OllamaGen.html#schema/0"},{"type":"function","title":"Schema - Omni.Providers.OllamaGen.schema/0","doc":"* `:model` (`t:String.t/0`) - Required. The ollama model name.\n\n* `:prompt` (`t:String.t/0`) - Required. Prompt to generate a response for.\n\n* `:images` (list of `t:String.t/0`) - A list of Base64 encoded images to be included with the prompt (for multimodal models only).\n\n* `:system` (`t:String.t/0`) - System prompt, overriding the model default.\n\n* `:template` (`t:String.t/0`) - Prompt template, overriding the model default.\n\n* `:context` - The context parameter returned from a previous call (enabling short conversational memory).\n\n* `:format` (`t:String.t/0`) - Set the expected format of the response (`json`).\n\n* `:raw` (`t:boolean/0`) - Set `true` if specifying a fully templated prompt. (`:template` is ingored)\n\n* `:stream` (`t:boolean/0`) - Whether to stream the response. The default value is `false`.\n\n* `:keep_alive` - How long to keep the model loaded.\n\n* `:options` - Additional advanced [model parameters](https://github.com/jmorganca/ollama/blob/main/docs/modelfile.md#valid-parameters-and-values).","ref":"Omni.Providers.OllamaGen.html#schema/0-schema"},{"type":"module","title":"Omni.Providers.OpenAI","doc":"Provider implementation for the [OpenAI Chat API](https://platform.openai.com/docs/api-reference/chat).\nUse this Provider to chat with any of the [Chat GPT](https://platform.openai.com/docs/models)\nmodels.","ref":"Omni.Providers.OpenAI.html"},{"type":"module","title":"Authorization - Omni.Providers.OpenAI","doc":"Obtain an API key from the [OpenAI Developer Dashboard](https://platform.openai.com/api-keys)\nand add it to your application's `config.exs`:\n\n```elixir\nconfig :omni, Omni.Providers.OpenAI, \"sk-proj-notarealkey\"\n```\n\nAlternatively, pass the API key to `Onmi.init/2`:\n\n```elixir\niex> Omni.init(:openai, api_key: api_key)\n%Omni.Provider{mod: Omni.Providers.OpenAI, req: %Req.Request{}}\n```","ref":"Omni.Providers.OpenAI.html#module-authorization"},{"type":"module","title":"OpenAI configuration - Omni.Providers.OpenAI","doc":"This Provider accepts the following initialization options:\n\n- `:organization_id` - When given, sets the `openai-organization` header.\n- `:project_id` - When given, sets the `openai-project` header.","ref":"Omni.Providers.OpenAI.html#module-openai-configuration"},{"type":"module","title":"Base URL - Omni.Providers.OpenAI","doc":"Many LLM providers mirror OpenAI's API. In such cases, you can use this\nProvider module and pass the `:base_url` option to `Omni.init/2`:\n\n```elixir\niex> Omni.init(:ollama, base_url: \"https://api.together.xyz/v1\")\n%Omni.Provider{mod: Omni.Providers.OpenAI, req: %Req.Request{}}\n```","ref":"Omni.Providers.OpenAI.html#module-base-url"},{"type":"function","title":"Omni.Providers.OpenAI.schema/0","doc":"Returns the schema for this Provider.","ref":"Omni.Providers.OpenAI.html#schema/0"},{"type":"function","title":"Schema - Omni.Providers.OpenAI.schema/0","doc":"* `:model` (`t:String.t/0`) - Required. Name of the model to use.\n\n* `:messages` (list of `t:map/0`) - Required. A list of messages comprising the conversation so far.\n\n* `:logit_bias` (map of `t:String.t/0` keys and `t:integer/0` values) - Modify the likelihood of specified tokens appearing in the completion.\n\n* `:log_probs` (`t:boolean/0`) - Whether to return log probabilities of the output tokens or not.\n\n* `:top_logprobs` - An integer between 0 and 20 specifying the number of most likely tokens to return at each token position.\n\n* `:max_tokens` (`t:non_neg_integer/0`) - The maximum number of tokens that can be generated in the chat completion.\n\n* `:n` (`t:non_neg_integer/0`) - How many chat completion choices to generate for each input message.\n\n* `:frequency_penalty` (`t:float/0`) - Number between -2.0 and 2.0.\n\n* `:presence_penalty` (`t:float/0`) - Number between -2.0 and 2.0.\n\n* `:response_format` (`t:map/0`) - An object specifying the format that the model must output.\n\n  * `:type`\n\n* `:seed` (`t:integer/0`) - If specified, system will make a best effort to sample deterministically.\n\n* `:stop` - Up to 4 sequences where the API will stop generating further tokens.\n\n* `:stream` (`t:boolean/0`) - If set, partial message deltas will be sent.\n\n* `:stream_options` (`t:map/0`) - Options for streaming response.\n\n  * `:include_usage` (`t:boolean/0`) - If set, an additional usage stats chunk will be streamed.\n\n* `:temperature` (`t:float/0`) - What sampling temperature to use, between 0 and 2.\n\n* `:top_p` (`t:float/0`) - An alternative to sampling with temperature, called nucleus sampling.\n\n* `:tools` (list of `t:map/0`) - A list of tools the model may call.\n\n* `:tool_choice` - Controls which (if any) tool is called by the model.\n\n* `:user` (`t:String.t/0`) - A unique identifier representing your end-user.","ref":"Omni.Providers.OpenAI.html#schema/0-schema"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}